#!/usr/bin/env python3

import sys
import os
import dynamo

USAGE = '''
dynamo <input-file> <output-file>
'''


def main():
    if len(sys.argv) != 3:
        print(USAGE)
        exit()

    input_file, output_file = sys.argv[1:]
    dynamo.remove_annotations_from_file(input_file, output_file)
    print('OK')

if __name__ == '__main__':
    main()



from setuptools import setup

setup(
    name='dynamo-mypy',
    version='0.0.2',
    description='remove annotations',
    author='Alexander Ivanov',
    author_email='alehander42@gmail.com',
    url='https://github.com/alehander42/dynamo',
    download_url='https://github.com/alehander42/dynamo/archive/v0.0.1.tar.gz',
    keywords=['mypy', 'annotation'],
    packages=['dynamo'],
    license='MIT',
    install_requires=[
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
    ],
    entry_points={
        'console_scripts': [
            'dynamo=dynamo.main:main',
        ],
    },
)



import ast
import astunparse
from typing import List, Optional

def remove_annotations_from_file(file: str, output: str) -> None:
    with open(file, 'r') as f:
        source = f.read()
    removed = remove_annotations(source)
    with open(output, 'w') as f:
        f.write(removed)

def remove_annotations(source: str) -> str:
    return astunparse.unparse(remove_annotations_in_ast(ast.parse(source)))

def remove_annotations_in_ast(node: ast.AST) -> ast.AST:
    return Remover().visit(node)

class Remover(ast.NodeTransformer):
    def visit_FunctionDef(self, node: ast.FunctionDef) -> Optional[ast.AST]:
        self.visit(node.args)
        if node.returns is not None:
            node.returns = None
        return node

    def visit_arg(self, node: ast.arg) -> Optional[ast.AST]:
        if node.annotation is not None:
            node.annotation = None
        return node

    def visit_alias(self, node: ast.alias) -> Optional[ast.AST]:
        if node.name == 'typing':
            return None
        return node

    def visit_ImportFrom(self, node: ast.ImportFrom) -> Optional[ast.AST]:
        if node.module == 'typing' or node.module == 'mypy_extension':
            return None
        return node


    